@@ -8,7 +8,7 @@ use DynaLoader ();
 use vars qw($VERSION @ISA);
 use vars qw{$err $errstr $drh $sqlite_version};
 BEGIN {
-    $VERSION = '1.22_08';
+    $VERSION = '1.24_01';
     @ISA     = ('DynaLoader');
 
     # Initialize errors
@@ -65,7 +65,7 @@ sub connect {
 
     # To avoid unicode and long file name problems on Windows,
     # convert to the shortname if the file (or parent directory) exists.
-    if ( $^O eq 'MSWin32' and $real ne ':memory:' ) {
+    if ( $^O =~ /MSWin32|cygwin/ and $real ne ':memory:' ) {
         require Win32;
         require File::Basename;
         my ($file, $dir, $suffix) = File::Basename::fileparse($real);
@@ -81,6 +81,15 @@ sub connect {
             # SQLite can't do mkpath anyway.
             # So let it go through as it and fail.
         }
+        if ( $^O eq 'cygwin' ) {
+            if ( $] >= 5.010 ) {
+                $real = Cygwin::win_to_posix_path($real, 'absolute');
+            }
+            else {
+                require Filesys::CygwinPaths;
+                $real = Filesys::CygwinPaths::fullposixpath($real);
+            }
+        }
     }
 
     # Hand off to the actual login function
